15.1. cdist-type__acl(7) — cdist 4.10.4 documentation

# 15.1. cdist-type__acl(7)

## 15.1.1. NAME

cdist-type__acl - Basic wrapper around setfacl

## 15.1.2. DESCRIPTION

ACL must be defined as 3-symbol combination, using r, w, x and -.

See setfacl(1) and acl(5) for more details.

## 15.1.3. OPTIONAL MULTIPLE PARAMETERS

user
  Add user ACL entry.
group
  Add group ACL entry.

## 15.1.4. BOOLEAN PARAMETERS

recursive
  Operate recursively (Linux only).
default
  Add default ACL entries.
remove
  Remove undefined ACL entries (Solaris not supported).

## 15.1.5. EXAMPLES

    __acl /srv/project \
        --recursive \
        --default \
        --remove \
        --user alice:rwx \
        --user bob:r-x \
        --group project-group:rwx \
        --group some-other-group:r-x

## 15.1.6. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 15.1.7. COPYING

Copyright (C) 2018 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.